Trait WithFilters
pub trait WithFilters {
// Required method
fn filters(&self) -> &[InstructionFilter];
}Expand description
Types that represent groups of instructions. The group of instructions can be described using a set of filters.
Required Methods
fn filters(&self) -> &[InstructionFilter]
fn filters(&self) -> &[InstructionFilter]
Returns a set of (potentially overlapping) filters that cover the entire area covered by the type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".